California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 035 - PROVIDES PERMANENT FUNDING FOR MEDI-CAL HEALTH CARE SERVICES. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1452181 | PLANNED PARENTHOOD ADVOCACY PROJECT LOS ANGELES COUNTY - YES ON PROP 35 (NONPROFIT 501 (C) (4) ) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1462573 | YES ON 35 - PROTECT OUR HEALTHCARE, A COALITION OF FIRST RESPONDERS, HEALTHCARE WORKERS, DOCTORS, NON-PROFIT COMMUNITY HEALTH CENTERS AND HOSPITALS | SUPPORT